# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from oceanbolt.com.distancecalculator_v3.services.distance_calculator_service.client import DistanceCalculatorServiceClient
from oceanbolt.com.distancecalculator_v3.services.distance_calculator_service.async_client import DistanceCalculatorServiceAsyncClient

from oceanbolt.com.distancecalculator_v3.types.service import BatchDistanceRequest
from oceanbolt.com.distancecalculator_v3.types.service import BatchDistanceResponse
from oceanbolt.com.distancecalculator_v3.types.service import DistanceRequest
from oceanbolt.com.distancecalculator_v3.types.service import DistanceResponse
from oceanbolt.com.distancecalculator_v3.types.service import Leg
from oceanbolt.com.distancecalculator_v3.types.service import Location
from oceanbolt.com.distancecalculator_v3.types.service import Point

__all__ = ('DistanceCalculatorServiceClient',
    'DistanceCalculatorServiceAsyncClient',
    'BatchDistanceRequest',
    'BatchDistanceResponse',
    'DistanceRequest',
    'DistanceResponse',
    'Leg',
    'Location',
    'Point',
)
